# API Reference

This section provides detailed documentation for all public modules, classes, and functions in the Factrainer library.

## Public API

Factrainer consists of the following sub-packages:

- **[factrainer.core](core/index.md)**: Main cross-validation functionality that is installed by default. Used in combination with the following framework-specific plugin packages.
- **[factrainer.lightgbm](lightgbm/index.md)**: Optionally installable plugin package for LightGBM integration.
- **[factrainer.sklearn](sklearn/index.md)**: Optionally installable plugin package for Scikit-learn integration.
- **[factrainer.xgboost](xgboost/index.md)**: Optionally installable plugin package for XGBoost integration (planned for future release).
- **[factrainer.catboost](catboost/index.md)**: Optionally installable plugin package for CatBoost integration (planned for future release).
